!! Copyright (C) 2004-2007 M. Oliveira, F. Nogueira
!!
!! This program is free software; you can redistribute it and/or modify
!! it under the terms of the GNU General Public License as published by
!! the Free Software Foundation; either version 2, or (at your option)
!! any later version.
!!
!! This program is distributed in the hope that it will be useful,
!! but WITHOUT ANY WARRANTY; without even the implied warranty of
!! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!! GNU General Public License for more details.
!!
!! You should have received a copy of the GNU General Public License
!! along with this program; if not, write to the Free Software
!! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
!! 02111-1307, USA.

#include "global.h"

module output
  use global
  use io
  use messages
  implicit none


                    !---Global Variables---!

  integer :: out_ae
  integer :: out_pp
  integer :: out_kb
  integer :: out_tests



                    !---Public/Private Statements---!

  private
  public :: output_ae_init, &
            output_pp_init, &
            output_kb_init, &
            output_tests_init, &
            output_end, &
            out_ae, &
            out_pp, &
            out_kb, &
            out_tests


contains

  subroutine output_ae_init()
    !-----------------------------------------------------------------------!
    ! Creates the "ae" directory and opens the file "ae/info".              !
    !-----------------------------------------------------------------------!
    integer :: iostat

    call push_sub("output_ae_init")

    !Create directory
    call sys_mkdir('ae')

    !Open file
    call io_assign(out_ae)
    open(out_ae, file='ae/info', status='unknown', iostat=iostat)
    if (iostat > 0) then
      write(message(1),'("Unable to open file ''ae/info''")')
      call write_fatal(1)
    end if

    call pop_sub()
  end subroutine output_ae_init

  subroutine output_pp_init()
    !-----------------------------------------------------------------------!
    ! Creates the "pp" directory and opens the file "pp/info".              !
    !-----------------------------------------------------------------------!
    integer :: iostat

    call push_sub("output_pp_init")

    !Create directory
    call sys_mkdir('pp')

    !Open file
    call io_assign(out_pp)
    open(out_pp, file='pp/info', status='unknown', iostat=iostat)
    if (iostat > 0) then
      write(message(1),'("Unable to open file ''pp/info''")')
      call write_fatal(1)
    end if

    call pop_sub()
  end subroutine output_pp_init

  subroutine output_kb_init()
    !-----------------------------------------------------------------------!
    ! Creates the "kb" directory and opens the file "kb/info".              !
    !-----------------------------------------------------------------------!
    integer :: iostat

    call push_sub("output_kb_init")

    !Create directory
    call sys_mkdir('kb')

    !Open file
    call io_assign(out_kb)
    open(out_kb, file='kb/info', status='unknown', iostat=iostat)
    if (iostat > 0) then
      write(message(1),'("Unable to open file ''kb/info''")')
      call write_fatal(1)
    end if

    call pop_sub()
  end subroutine output_kb_init

  subroutine output_tests_init()
    !-----------------------------------------------------------------------!
    ! Creates the "tests" directory and opens the file "tests/info".        !
    !-----------------------------------------------------------------------!
    integer :: iostat

    call push_sub("output_tests_init")

    !Create directory
    call sys_mkdir('tests')

    !Open file
    call io_assign(out_tests)
    open(out_tests, file='tests/info', status='unknown', iostat=iostat)
    if (iostat > 0) then
      write(message(1),'("Unable to open file ''tests/info''")')
      call write_fatal(1)
    end if

    call pop_sub()
  end subroutine output_tests_init

  subroutine output_end()
    !-----------------------------------------------------------------------!
    ! Closes the opened */info files.                                       !
    !-----------------------------------------------------------------------!
    logical :: opened

    call push_sub("output_end")

    inquire(out_ae, opened = opened)
    if (.not. opened) close(out_ae)

    inquire(out_pp, opened = opened)
    if (.not. opened) close(out_pp)

    inquire(out_tests, opened = opened)
    if (.not. opened) close(out_tests)

    call pop_sub()
  end subroutine output_end

end module output
